@@ -5,7 +5,6 @@ use std::{
 };
 
 use itertools::Itertools;
-use maplit::hashset;
 use ruma_common::MilliSecondsSinceUnixEpoch;
 use ruma_events::{
     room::{
@@ -193,7 +192,10 @@ impl StateResolution {
                 state_sets.iter().map(|state_set| state_set.get(key)).collect::<Vec<_>>();
 
             if event_ids.iter().all_equal() {
-                let id = event_ids.remove(0).expect("unconflicting `EventId` is not None");
+                // First .unwrap() is okay because
+                // * event_ids has the same length as state_sets
+                // * we never enter the loop this code is in if state_sets is empty
+                let id = event_ids.pop().unwrap().expect("unconflicting `EventId` is not None");
                 unconflicted_state.insert(key.clone(), id.clone());
             } else {
                 conflicted_state
@@ -217,7 +219,7 @@ impl StateResolution {
 
             Ok(auth_chain_sets.into_iter().flatten().filter(|id| !common.contains(id)).collect())
         } else {
-            Ok(hashset![])
+            Ok(HashSet::new())
         }
     }
 
@@ -303,7 +305,7 @@ impl StateResolution {
 
         // The number of events that depend on the given event (the EventId key)
         // How many events reference this event in the DAG as a parent
-        let mut reverse_graph = HashMap::new();
+        let mut reverse_graph: HashMap<&EventId, HashSet<&EventId>> = HashMap::new();
 
         // Vec of nodes that have zero out degree, least recent events.
         let mut zero_outdegree = vec![];
@@ -315,9 +317,9 @@ impl StateResolution {
                 zero_outdegree.push(Reverse((key_fn(node)?, node)));
             }
 
-            reverse_graph.entry(node).or_insert(hashset![]);
+            reverse_graph.entry(node).or_default();
             for edge in edges {
-                reverse_graph.entry(edge).or_insert(hashset![]).insert(node);
+                reverse_graph.entry(edge).or_default().insert(node);
             }
         }
 
@@ -614,10 +616,8 @@ impl StateResolution {
         F: Fn(&EventId) -> Option<Arc<E>>,
     {
         let mut state = vec![event_id.clone()];
-        while !state.is_empty() {
-            // We just checked if it was empty so unwrap is fine
-            let eid = state.pop().unwrap();
-            graph.entry(eid.clone()).or_insert(hashset![]);
+        while let Some(eid) = state.pop() {
+            graph.entry(eid.clone()).or_default();
             // Prefer the store to event as the store filters dedups the events
             for aid in &fetch_event(&eid).map(|ev| ev.auth_events()).unwrap_or_default() {
                 if auth_diff.contains(aid) {
